import { InternalLink, KeyValueTable } from "@ess-ics/ce-ui-common";
import { isDeploymentJob } from "./JobUtils";
import { JobRevisionChip } from "./JobRevisionChip";
import { JobHost } from "./JobHost";
import { JobDetails } from "../../store/deployApi";

interface JobDetailsSingleJobProps {
  job: JobDetails;
}

const getRevision = (operation: JobDetails) => {
  return {
    revision:
      operation.gitReference && operation.gitProjectId ? (
        <JobRevisionChip
          gitReference={operation.gitReference}
          gitProjectId={operation.gitProjectId}
        />
      ) : (
        "Unknown"
      )
  };
};

const getSingleOperationFields = (
  operation: JobDetails,
  isDeployJob: boolean
) => {
  return {
    ioc: (
      <InternalLink
        to={`/iocs/${operation.iocName}`}
        label={`IOC details, ${operation.iocName}`}
      >
        {operation.iocName}
      </InternalLink>
    ),
    ...(isDeployJob && getRevision(operation)),
    host: <JobHost job={operation} />
  };
};

export const JobDetailsSingleJob = ({ job }: JobDetailsSingleJobProps) => {
  const isDeployJob = isDeploymentJob(job.action);
  return (
    <KeyValueTable
      obj={getSingleOperationFields(job, isDeployJob)}
      variant="overline"
      sx={{ border: 0 }}
      valueOptions={{ headerName: "" }}
    />
  );
};
